@@ -20,6 +20,7 @@
 #include <qcombobox.h>
 #include <qspinbox.h>
 #include <qframe.h>
+#include <qdesktopwidget.h>
 
 #include <kconfig.h>
 #include <kglobal.h>
@@ -94,11 +95,24 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
   mColorContext = QColor::enterAllocContext();
 
   mEffectRunning = false;
-  loadNextImage();
-  createNextScreen();
 
   mTimer.start(10, true);
   connect(&mTimer, SIGNAL(timeout()), SLOT(slotTimeout()));
+
+  QDesktopWidget *d = QApplication::desktop();
+  if( geometry() == d->geometry() && d->numScreens() > 1)
+  {
+	for(int i = 0; i < d->numScreens(); ++i)
+	{
+		QRect s = d->screenGeometry(i);
+		mGeoList.append(new mScreenGeo(s.width(), s.height(), s.topLeft().x(), s.topLeft().y()));
+	}
+   }
+   else
+   {
+	mGeoList.append(new mScreenGeo(width(), height(), 0, 0 ));
+   }
+   createNextScreen();
 }
 
 
@@ -724,12 +738,17 @@ void kSlideShowSaver::createNextScreen()
 
   mNextScreen.fill(black);
 
-  ww = mNextScreen.width();
-  wh = mNextScreen.height();
+  p.begin(&mNextScreen);
+  
+  mScreenGeo *geoptr = 0;
+  for(geoptr = mGeoList.first(); geoptr; geoptr = mGeoList.next())
+  {
+    loadNextImage();
+    
   iw = mImage.width();
   ih = mImage.height();
-
-  p.begin(&mNextScreen);
+    ww = geoptr->mW;
+    wh = geoptr->mH;
 
   if (mFileList.isEmpty())
   {
@@ -749,14 +768,14 @@ void kSlideShowSaver::createNextScreen()
       ih = (int)(ih * fx);
       QImage scaledImg = mImage.smoothScale(iw, ih);
 
-      x = (ww - iw) >> 1;
-      y = (wh - ih) >> 1;
+        x = ((ww - iw) >> 1) + geoptr->mXorg;
+        y = ((wh - ih) >> 1) + geoptr->mYorg;
 
       p.drawImage(x, y, scaledImg);
     }
     else
     {
-      if(iw > ww || ih > wh)
+      if(iw >= ww || ih >= wh)
       {
         fx = (double)ww / iw;
 	fy = (double)wh / ih;
@@ -766,8 +785,8 @@ void kSlideShowSaver::createNextScreen()
 	ih = (int)(ih * fx);
 	QImage scaledImg = mImage.smoothScale(iw, ih);
 
-	x = (ww - iw) >> 1;
-	y = (wh - ih) >> 1;
+          x = ((ww - iw) >> 1) + geoptr->mXorg;
+          y = ((wh - ih) >> 1) + geoptr->mYorg;
 
 	p.drawImage(x, y, scaledImg);
       }
@@ -775,13 +794,13 @@ void kSlideShowSaver::createNextScreen()
       {
         if(mRandomPosition)
         {
-          x = rand() % (ww - iw);
-          y = rand() % (wh - ih);
+            x = (rand() % (ww - iw)) + geoptr->mXorg;
+            y = (rand() % (wh - ih)) + geoptr->mYorg;
         }
         else
         {
-          x = (ww - iw) >> 1;
-          y = (wh - ih) >> 1;
+            x = ((ww - iw) >> 1) + geoptr->mXorg;
+            y = ((wh - ih) >> 1) + geoptr->mYorg;
         }
 
         // bitBlt(&mNextScreen, x, y, &mImage, 0, 0, iw, ih, CopyROP, false);
@@ -794,12 +813,12 @@ void kSlideShowSaver::createNextScreen()
       p.setPen(QColor("black"));
       for (x=9; x<=11; x++)
 	for (y=21; y>=19; y--)
-	  p.drawText(x, wh-y, mImageName);
+            p.drawText(x + geoptr->mXorg, wh-y+geoptr->mYorg, mImageName);
       p.setPen(QColor("white"));
-      p.drawText(10, wh-20, mImageName);
+        p.drawText(10 + geoptr->mXorg, wh-20 + geoptr->mYorg, mImageName);
+      }
     }
   }
-
   p.end();
 }
 
