@@ -70,7 +70,6 @@ static const int MAXGRADIENTSIZE = 64;
 
 static unsigned contrast = 110;
 
-QMap<unsigned int, QIntDict<GradientSet> > gradients; // gradients[color][size]
 
 //////////////////////////////////////////////////////////////////////////////
 // Construction, Destruction, Initialization                                //
@@ -95,6 +94,8 @@ PhaseStyle::PhaseStyle()
     highlights_ =
         settings.readBoolEntry("/phasestyle/Settings/highlights", true);
 
+    gradients = new QMap<unsigned int, QIntDict<GradientSet> >;
+
     reverse_ = QApplication::reverseLayout();
 
     // create bitmaps
@@ -120,7 +121,11 @@ PhaseStyle::PhaseStyle()
     doodad_light = QBitmap(4, 4, doodad_light_bits, true);
 }
 
-PhaseStyle::~PhaseStyle() { ; }
+PhaseStyle::~PhaseStyle() 
+{
+    delete gradients;
+    gradients = 0;
+}
 
 //////////////////////////////////////////////////////////////////////////////
 // Polishing                                                                //
@@ -179,7 +184,7 @@ void PhaseStyle::polish(QWidget *widget)
 void PhaseStyle::polish(QPalette &pal)
 {
     // clear out gradients on a color change
-    gradients.clear();
+    gradients->clear();
 
     // lighten up a bit, so the look is not so "crisp"
     if (QPixmap::defaultDepth() > 8) { // but not on low color displays
@@ -258,11 +263,11 @@ void PhaseStyle::drawPhaseGradient(QPainter *painter,
         painter->fillRect(rect, color);
     } else {
         // lazy allocation
-        GradientSet *set = gradients[color.rgb()][size];
+        GradientSet *set = (*gradients)[color.rgb()][size];
         if (!set) {
             set = new GradientSet(color, size);
-            gradients[color.rgb()].setAutoDelete(true);
-            gradients[color.rgb()].insert(size, set);
+            (*gradients)[color.rgb()].setAutoDelete(true);
+            (*gradients)[color.rgb()].insert(size, set);
         }
         painter->drawTiledPixmap(rect, *set->gradient(horizontal, reverse),
                                  QPoint(px, py));
